#version 460

#include "/lib/settings.glsl"

out vec4 tintColor;

out vec3 normal;

uniform vec3 fogColor;

in vec3 vaPosition;
in vec4 vaColor;
uniform mat4 modelViewMatrix;
uniform mat4 projectionMatrix;

uniform float far;
uniform float near;

uniform float rainStrength;
uniform int isEyeInWater;
uniform float blindness;

void main() {
	vec4 position = projectionMatrix * modelViewMatrix * vec4(vaPosition, 1.0);

	gl_Position = position;

	float depth = position.z / position.w;
	float linearDepth = 2.0 * near * far / (far + near - (2.0 * depth - 1.0) * (far - near));

	float fogStrength = (FOG_STRENGTH * 0.025 + rainStrength * RAIN_FOG + isEyeInWater * WATER_FOG + blindness * BLINDNESS_FOG) / (far * far * far);
	float fogDistance = 25.0 + linearDepth;
	float fog = clamp(fogDistance * fogDistance * fogDistance * fogDistance * fogStrength, 0.0, 1.0);

	tintColor = vec4(vaColor.rgb + fogColor, vaColor.a * clamp(linearDepth * 0.01, 0.0, 1.0 - fog));
}